# modified from the python library faker:
# https://github.com/joke2k/faker/blob/master/faker/providers/job/zh_TW/__init__.py

job_formats_zh_tw <- c(
  "BIOS\u5de5\u7a0b\u5e2b",
  "CAD\uff0fCAM\u5de5\u7a0b\u5e2b",
  "CNC\u6a5f\u53f0\u64cd\u4f5c\u4eba\u54e1",
  "CNC\u96fb\u8166\u7a0b\u5f0f\u7de8\u6392\u4eba\u54e1",
  "EMC\uff0f\u96fb\u5b50\u5b89\u898f\u5de5\u7a0b\u5e2b",
  "FAE\u5de5\u7a0b\u5e2b",
  "IC\u4f48\u5c40\u5de5\u7a0b\u5e2b",
  "IC\u5c01\u88dd\uff0f\u6e2c\u8a66\u5de5\u7a0b\u5e2b",
  "ISO\uff0f\u54c1\u4fdd\u4eba\u54e1",
  "Internet\u7a0b\u5f0f\u8a2d\u8a08\u5e2b",
  "LCD\u88fd\u7a0b\u5de5\u7a0b\u5e2b",
  "LCD\u8a2d\u5099\u5de5\u7a0b\u5e2b",
  "MES\u5de5\u7a0b\u5e2b",
  "MIS\u7a0b\u5f0f\u8a2d\u8a08\u5e2b",
  "MIS\uff0f\u7db2\u7ba1\u4e3b\u7ba1",
  "OP\uff0f\u65c5\u884c\u793e\u4eba\u54e1",
  "PCB\u4f48\u7dda\u5de5\u7a0b\u5e2b",
  "PCB\u6280\u8853\u4eba\u54e1",
  "RF\u901a\u8a0a\u5de5\u7a0b\u5e2b",
  "SMT\u5de5\u7a0b\u5e2b",
  "\u4e00\u822c\u52d5\u7269\u98fc\u80b2\u5de5\u4f5c\u8005",
  "\u4e0d\u52d5\u7522\u7522\u6b0a\u5be9\u6838\uff0f\u4f30\u50f9\u5e2b",
  "\u4e0d\u52d5\u7522\u7d93\u7d00\u4eba",
  "\u4e0d\u52d5\u7522\uff0f\u5546\u5834\u958b\u767c\u4eba\u54e1",
  "\u4e2d\u7b49\u5b78\u6821\u6559\u5e2b",
  "\u4e2d\u91ab\u5e2b",
  "\u4e2d\u9910\u5eda\u5e2b",
  "\u4e3b\u6301\u4eba",
  "\u4e3b\u7ba1\u7279\u5225\u52a9\u7406",
  "\u4e3b\u8fa6\u6703\u8a08",
  "\u4eba\u529b\u8cc7\u6e90\u4e3b\u7ba1",
  "\u4eba\u529b\u8cc7\u6e90\u4eba\u54e1",
  "\u4eba\u529b\u8cc7\u6e90\u52a9\u7406",
  "\u4eba\u529b\uff0f\u5916\u52de\u4ef2\u4ecb",
  "\u4ee3\u66f8\uff0f\u5730\u653f\u58eb",
  "\u4f30\u7b97\u4eba\u54e1",
  "\u4f5c\u66f2\u5bb6",
  "\u4f5c\u696d\u54e1\uff0f\u5305\u88dd\u54e1",
  "\u4fdd\u5168\u4eba\u54e1\uff0f\u8b66\u885b",
  "\u4fdd\u5168\u6280\u8853\u4eba\u54e1",
  "\u4fdd\u5b89\u670d\u52d9\u5de5\u4f5c",
  "\u4fdd\u7a05\u4eba\u54e1",
  "\u4fdd\u96aa\u696d\u52d9\uff0f\u7d93\u7d00\u4eba",
  "\u5009\u5132\u7269\u6d41\u4eba\u54e1",
  "\u5009\u7ba1",
  "\u50ac\u6536\u4eba\u54e1",
  "\u50b3\u64ad\u5a92\u9ad4\u4f01\u5283\u4eba\u54e1",
  "\u50b3\u92b7\u4eba\u54e1",
  "\u5132\u5099\u5e79\u90e8",
  "\u5149\u5b78\u5de5\u7a0b\u5e2b",
  "\u5149\u96fb\u5de5\u7a0b\u5e2b",
  "\u5149\u96fb\u5de5\u7a0b\u7814\u767c\u4e3b\u7ba1",
  "\u5167\u696d\u5de5\u7a0b\u5e2b",
  "\u516c\u5171\u885b\u751f\u4eba\u54e1",
  "\u516c\u5171\u885b\u751f\u91ab\u5e2b",
  "\u516c\u5bb6\u6a5f\u95dc\u4eba\u54e1",
  "\u5238\u5546\u5f8c\u7dda\u4eba\u54e1",
  "\u526f\u6559\u6388",
  "\u52a0\u6cb9\u54e1",
  "\u52a9\u6559",
  "\u52a9\u7406\u5de5\u7a0b\u5e2b",
  "\u52a9\u7406\u6559\u6388",
  "\u52de\u5de5\u5b89\u5168\u885b\u751f\u7ba1\u7406\u4eba\u54e1",
  "\u52de\u5de5\u5b89\u5168\u885b\u751f\u7ba1\u7406\u5e2b",
  "\u5305\u88dd\u8a2d\u8a08",
  "\u5316\u5b78\u5de5\u7a0b\u7814\u767c\u4eba\u54e1",
  "\u5316\u5b78\u7814\u7a76\u54e1",
  "\u5316\u5de5\u5316\u5b78\u5de5\u7a0b\u5e2b",
  "\u5347\u5b78\u88dc\u7fd2\u73ed\u8001\u5e2b",
  "\u534a\u5c0e\u9ad4\u5de5\u7a0b\u5e2b",
  "\u534a\u5c0e\u9ad4\u88fd\u7a0b\u5de5\u7a0b\u5e2b",
  "\u534a\u5c0e\u9ad4\u8a2d\u5099\u5de5\u7a0b\u5e2b",
  "\u5370\u524d\u88fd\u4f5c\uff0f\u5370\u5237\u6280\u8853\u4eba\u54e1",
  "\u53ef\u9760\u5ea6\u5de5\u7a0b\u5e2b",
  "\u540a\u8eca\uff0f\u8d77\u91cd\u6a5f\u8a2d\u5099\u64cd\u4f5c\u54e1",
  "\u547c\u5438\u6cbb\u7642\u5e2b",
  "\u54c1\u724c\u5ba3\u50b3\u53ca\u5a92\u9ad4\u516c\u95dc",
  "\u54c1\u7ba1\uff0f\u54c1\u4fdd\u4e3b\u7ba1",
  "\u54c1\u7ba1\uff0f\u54c1\u4fdd\u5de5\u7a0b\u5e2b",
  "\u54c1\u7ba1\uff0f\u6aa2\u9a57\u4eba\u54e1",
  "\u54f2\u5b78\uff0f\u6b77\u53f2\uff0f\u653f\u6cbb\u7814\u7a76\u4eba\u54e1",
  "\u552e\u7968\uff0f\u6536\u9280\u4eba\u54e1",
  "\u5546\u696d\u8a2d\u8a08",
  "\u5546\u6a19\uff0f\u5c08\u5229\u4eba\u54e1",
  "\u5674\u6f06\u4eba\u54e1",
  "\u570b\u5167\u696d\u52d9\u4e3b\u7ba1",
  "\u570b\u5167\u696d\u52d9\u4eba\u54e1",
  "\u570b\u5916\u696d\u52d9\u4e3b\u7ba1",
  "\u570b\u5916\u696d\u52d9\u4eba\u54e1",
  "\u570b\u5c0f\u5b78\u6821\u6559\u5e2b",
  "\u570b\u8cbf\u4eba\u54e1",
  "\u5716\u66f8\u8cc7\u6599\u7ba1\u7406\u4eba\u54e1",
  "\u571f\u5730\u958b\u767c\u4eba\u54e1",
  "\u571f\u6728\u6280\u5e2b\uff0f\u571f\u6728\u5de5\u7a0b\u5e2b",
  "\u5730\u52e4\u4eba\u54e1",
  "\u5730\u8cea\u8207\u5730\u7403\u79d1\u5b78\u7814\u7a76\u54e1",
  "\u5851\u81a0\u5c04\u51fa\u6280\u8853\u4eba\u54e1",
  "\u5851\u81a0\u6a21\u5177\u6280\u8853\u4eba\u54e1",
  "\u5857\u88dd\u6280\u8853\u4eba\u54e1",
  "\u58d3\u9444\u6a21\u5177\u6280\u8853\u4eba\u54e1",
  "\u5916\u52d9\uff0f\u5feb\u905e\uff0f\u9001\u8ca8",
  "\u591a\u5a92\u9ad4\u52d5\u756b\u8a2d\u8a08\u5e2b",
  "\u591a\u5a92\u9ad4\u958b\u767c\u4e3b\u7ba1",
  "\u5927\u6a13\u7ba1\u7406\u54e1",
  "\u5927\u8ca8\u8eca\u53f8\u6a5f",
  "\u5929\u6587\u7814\u7a76\u54e1",
  "\u592a\u967d\u80fd\u6280\u8853\u5de5\u7a0b\u5e2b",
  "\u5a1b\u6a02\u4e8b\u696d\u4eba\u54e1",
  "\u5a92\u9ad4\u516c\u95dc\uff0f\u5ba3\u50b3\u63a1\u8cb7",
  "\u5b89\u5168\uff0f\u885b\u751f\u6aa2\u9a57\u4eba\u54e1",
  "\u5b89\u5fc3\u670d\u52d9\u54e1",
  "\u5b89\u89aa\u73ed\u8001\u5e2b",
  "\u5ba2\u6236\u670d\u52d9\u4e3b\u7ba1",
  "\u5ba2\u6236\u670d\u52d9\u4eba\u54e1",
  "\u5ba4\u5167\u8a2d\u8a08\uff0f\u88dd\u6f62\u4eba\u54e1",
  "\u5bb6\u4e8b\u670d\u52d9\u4eba\u54e1",
  "\u5bb6\u5ead\u4ee3\u5de5",
  "\u5be6\u9a57\u5316\u9a57\u4eba\u54e1",
  "\u5bf5\u7269\u7f8e\u5bb9\u5c08\u696d\u4eba\u54e1",
  "\u5c08\u6848\u696d\u52d9\u4e3b\u7ba1",
  "\u5c08\u6848\u7ba1\u7406\u4e3b\u7ba1",
  "\u5c08\u6848\u7ba1\u7406\u5e2b",
  "\u5c08\u79d1\u8b77\u7406\u5e2b",
  "\u5c0e\u64ad",
  "\u5c0e\u6f14",
  "\u5c0e\u904a",
  "\u5c0f\u5ba2\u8eca\u53f8\u6a5f",
  "\u5c0f\u8ca8\u8eca\u53f8\u6a5f",
  "\u5c45\u5bb6\u670d\u52d9\u7763\u5c0e\u54e1",
  "\u5c55\u5834\uff0f\u6ae5\u7a97\u4f48\u7f6e\u4eba\u54e1",
  "\u5de5\u52d9\u4eba\u54e1\uff0f\u52a9\u7406",
  "\u5de5\u5546\u767b\u8a18\u670d\u52d9\u4eba\u54e1",
  "\u5de5\u5730\u76e3\u5de5\uff0f\u4e3b\u4efb",
  "\u5de5\u5ee0\u4e3b\u7ba1",
  "\u5de5\u696d\u5de5\u7a0b\u5e2b\uff0f\u751f\u7522\u7dda\u898f\u5283",
  "\u5de5\u696d\u8a2d\u8a08",
  "\u5de5\u7a0b\u52a9\u7406",
  "\u5de5\u7a0b\u7814\u767c\u4e3b\u7ba1",
  "\u5de5\u7a0b\u914d\u7ba1\u7e6a\u5716",
  "\u5de5\u8b80\u751f",
  "\u5e02\u5834\u8abf\u67e5\uff0f\u5e02\u5834\u5206\u6790",
  "\u5e73\u9762\u8a2d\u8a08\uff0f\u7f8e\u7de8\u4eba\u54e1",
  "\u5e7c\u6559\u73ed\u8001\u5e2b",
  "\u5e97\u9577\uff0f\u8ce3\u5834\u7ba1\u7406\u4eba\u54e1",
  "\u5ee0\u52d9",
  "\u5ee0\u52d9\u52a9\u7406",
  "\u5ee3\u544aAE\u696d\u52d9\u4eba\u54e1",
  "\u5ee3\u544a\u4f01\u5283\u4e3b\u7ba1",
  "\u5ee3\u544a\u6587\u6848\uff0f\u4f01\u5283",
  "\u5ee3\u544a\u8a2d\u8a08",
  "\u5efa\u7bc9\u5e2b",
  "\u5efa\u7bc9\u7269\u6e05\u6f54\u5de5",
  "\u5efa\u7bc9\u7269\u96fb\u529b\u7cfb\u7d71\u7dad\u4fee\u5de5",
  "\u5efa\u7bc9\u8a2d\u8a08\uff0f\u7e6a\u5716\u4eba\u54e1",
  "\u5f71\u7247\u88fd\u4f5c\u6280\u8853\u4eba\u54e1",
  "\u5f8b\u5e2b",
  "\u5fa9\u5efa\u6280\u8853\u5e2b",
  "\u5fae\u6a5f\u96fb\u5de5\u7a0b\u5e2b",
  "\u5fc3\u7406\u5b78\u7814\u7a76\u4eba\u54e1",
  "\u5fd7\u5de5\u4eba\u54e1",
  "\u5fd7\u9858\u5f79\u8ecd\u5b98\uff0f\u58eb\u5b98\uff0f\u58eb\u5175",
  "\u61c9\u7528\u79d1\u5b78\u7814\u7a76\u54e1",
  "\u6210\u672c\u6703\u8a08",
  "\u624b\u5de5\u5305\u88dd\u5de5",
  "\u624d\u85dd\u985e\u8001\u5e2b",
  "\u6253\u7248\u4eba\u54e1",
  "\u6280\u8853\u6587\u4ef6\uff0f\u8aaa\u660e\u66f8\u7de8\u8b6f",
  "\u6309\u6469\uff0f\u63a8\u62ff\u5e2b",
  "\u6392\u7248\u4eba\u54e1",
  "\u63a1\u8cfc\u4e3b\u7ba1",
  "\u63a1\u8cfc\u4eba\u54e1",
  "\u63a1\u8cfc\u52a9\u7406",
  "\u63a8\u571f\u6a5f\u8a2d\u5099\u64cd\u4f5c\u54e1",
  "\u64ad\u97f3\uff0f\u914d\u97f3\u4eba\u54e1",
  "\u651d\u5f71\u52a9\u7406",
  "\u651d\u5f71\u5e2b",
  "\u653e\u5c04\u6027\u8a2d\u5099\u4f7f\u7528\u6280\u8853\u54e1",
  "\u6551\u751f\u54e1",
  "\u6559\u4fdd\u54e1",
  "\u6559\u6388",
  "\u6559\u80b2\u8a13\u7df4\u4eba\u54e1",
  "\u6574\u9ad4\u9020\u578b\u5e2b",
  "\u6578\u4f4dIC\u8a2d\u8a08\u5de5\u7a0b\u5e2b",
  "\u6578\u5b78\u7814\u7a76\u54e1",
  "\u6578\u7406\u88dc\u7fd2\u73ed\u8001\u5e2b",
  "\u6587\u4ef6\u7ba1\u7406\u5e2b",
  "\u6587\u7de8\uff0f\u6821\u5c0d\uff0f\u6587\u5b57\u5de5\u4f5c\u8005",
  "\u65c5\u904a\u4f11\u9592\u985e\u4e3b\u7ba1",
  "\u65e5\u5f0f\u5eda\u5e2b",
  "\u65e5\u6587\u7ffb\u8b6f\uff0f\u53e3\u8b6f\u4eba\u54e1",
  "\u661f\u8c61\u5360\u535c\u4eba\u54e1",
  "\u666f\u89c0\u8a2d\u8a08\u5e2b",
  "\u6703\u8a08\u5e2b",
  "\u670d\u88dd\uff0f\u76ae\u5305\uff0f\u978b\u985e\u8a2d\u8a08",
  "\u6728\u5de5",
  "\u6750\u6599\u7814\u767c\u4eba\u54e1",
  "\u677f\u91d1\u6280\u8853\u54e1",
  "\u6797\u6728\u4f10\u904b\u5de5\u4f5c\u8005",
  "\u67d3\u6574\u6280\u8853\u4eba\u54e1",
  "\u67e5\u5e33\uff0f\u5be9\u8a08\u4eba\u54e1",
  "\u6838\u4fdd\uff0f\u4fdd\u96aa\u5167\u52e4\u4eba\u54e1",
  "\u696d\u52d9\u52a9\u7406",
  "\u696d\u52d9\u652f\u63f4\u5de5\u7a0b\u5e2b",
  "\u6a02\u5668\u88fd\u9020\u54e1",
  "\u6a21\u7279\u5152",
  "\u6a5f\u68b0\u52a0\u5de5\u6280\u8853\u4eba\u54e1",
  "\u6a5f\u68b0\u5de5\u7a0b\u5e2b",
  "\u6a5f\u68b0\u64cd\u4f5c\u54e1",
  "\u6a5f\u68b0\u88dd\u914d\u54e1",
  "\u6a5f\u68b0\u8a2d\u8a08\uff0f\u7e6a\u5716\u4eba\u54e1",
  "\u6a5f\u69cb\u5de5\u7a0b\u5e2b",
  "\u6a5f\u96fb\u6280\u5e2b\uff0f\u5de5\u7a0b\u5e2b",
  "\u6ac3\u6aaf\u63a5\u5f85\u4eba\u54e1",
  "\u6c23\u8c61\u7814\u7a76\u54e1",
  "\u6c34\u4fdd\u5de5\u7a0b\u5e2b",
  "\u6c34\u4fdd\u6280\u5e2b",
  "\u6c34\u5229\u5de5\u7a0b\u5e2b",
  "\u6c34\u7522\u990a\u6b96\u5de5\u4f5c\u8005",
  "\u6c34\u96fb\u5de5",
  "\u6c34\u96fb\u5de5\u7a0b\u5e2b",
  "\u6c34\u96fb\u5de5\u7a0b\u7e6a\u5716\u4eba\u54e1",
  "\u6c7d\u8eca\u7f8e\u5bb9\u4eba\u54e1",
  "\u6c7d\u8eca\u92b7\u552e\u4eba\u54e1",
  "\u6c7d\u8eca\uff0f\u6a5f\u8eca\u5f15\u64ce\u6280\u8853\u4eba\u54e1",
  "\u6c7d\u8eca\uff0f\u6a5f\u8eca\u6280\u8853\u7dad\u4fee\u4eba\u54e1",
  "\u6c96\u58d3\u6a21\u5177\u6280\u8853\u4eba\u54e1",
  "\u6cb9\u6f06\u5de5",
  "\u6cbb\u7642\u5e2b",
  "\u6cd5\u52d9\u4eba\u54e1",
  "\u6cd5\u52d9\u52a9\u7406",
  "\u6cd5\u52d9\uff0f\u667a\u8ca1\u4e3b\u7ba1",
  "\u6cd5\u5f8b\u5c08\u696d\u4eba\u54e1",
  "\u6ce5\u6c34\u5c0f\u5de5",
  "\u6ce5\u6c34\u5de5",
  "\u6d17\u7897\u4eba\u54e1",
  "\u6d3b\u52d5\u4f01\u5283\u4eba\u54e1",
  "\u6d3e\u5831\u751f\uff0f\u50b3\u55ae\u6d3e\u9001",
  "\u6d88\u9632\u54e1",
  "\u6d88\u9632\u5c08\u696d\u4eba\u54e1",
  "\u6df7\u51dd\u571f\u5de5",
  "\u6e05\u6f54\u5de5",
  "\u6e2c\u8a66\u4eba\u54e1",
  "\u6f14\u54e1",
  "\u6f14\u594f\u5bb6",
  "\u6f14\u7b97\u6cd5\u958b\u767c\u5de5\u7a0b\u5e2b",
  "\u710a\u63a5\u53ca\u5207\u5272\u6280\u8853\u54e1",
  "\u7167\u9867\u6307\u5c0e\u54e1",
  "\u7167\u9867\u670d\u52d9\u54e1",
  "\u71b1\u50b3\u5de5\u7a0b\u5e2b",
  "\u71c8\u5149\uff0f\u97f3\u97ff\u5e2b",
  "\u71df\u5efa\u4e3b\u7ba1",
  "\u71df\u5efa\u69cb\u9020\u5de5",
  "\u71df\u9020\u5de5\u7a0b\u5e2b",
  "\u71df\u904b\u7ba1\u7406\u5e2b",
  "\u71df\u990a\u5e2b",
  "\u7259\u91ab\u52a9\u7406",
  "\u7259\u91ab\u5e2b",
  "\u7269\u7406\u6cbb\u7642\u5e2b",
  "\u7269\u7406\u7814\u7a76\u54e1",
  "\u7269\u7ba1\uff0f\u8cc7\u6750",
  "\u7279\u6b8a\u5de5\u7a0b\u5e2b",
  "\u7279\u6b8a\u6559\u80b2\u6559\u5e2b",
  "\u7279\u7528\u5316\u5b78\u5de5\u7a0b\u5e2b",
  "\u7378\u91ab\u5e2b",
  "\u73e0\u5bf6\u53ca\u8cb4\u91d1\u5c6c\u6280\u8853\u54e1",
  "\u73e0\u5fc3\u7b97\u8001\u5e2b",
  "\u7406\u8ce0\u4eba\u54e1",
  "\u74b0\u5883\u5de5\u7a0b\u5e2b",
  "\u751f\u547d\u79ae\u5100\u5e2b",
  "\u751f\u7269\u5b78\u5c08\u696d\u8207\u7814\u7a76",
  "\u751f\u7269\u79d1\u6280\u7814\u767c\u4eba\u54e1",
  "\u751f\u7522\u6280\u8853\uff0f\u88fd\u7a0b\u5de5\u7a0b\u5e2b",
  "\u751f\u7522\u7ba1\u7406\u4e3b\u7ba1",
  "\u751f\u7522\u8a2d\u5099\u5de5\u7a0b\u5e2b",
  "\u751f\u7ba1",
  "\u751f\u7ba1\u52a9\u7406",
  "\u751f\u9bae\u4eba\u54e1",
  "\u7522\u54c1\u4e8b\u696d\u8655\u4e3b\u7ba1",
  "\u7522\u54c1\u4f01\u5283\u4e3b\u7ba1",
  "\u7522\u54c1\u4f01\u5283\u958b\u767c\u4eba\u54e1",
  "\u7522\u54c1\u552e\u5f8c\u6280\u8853\u670d\u52d9",
  "\u7522\u54c1\u7ba1\u7406\u5e2b",
  "\u7522\u54c1\u7dad\u4fee\u4eba\u54e1",
  "\u7522\u54c1\u884c\u92b7\u4eba\u54e1",
  "\u75c5\u7406\u85e5\u7406\u7814\u7a76\u4eba\u54e1",
  "\u767c\u5305\u4eba\u54e1",
  "\u767c\u884c\u4f01\u5283\uff0f\u51fa\u7248\u4eba\u54e1",
  "\u780c\u78da\u5de5",
  "\u7814\u7a76\u4eba\u54e1",
  "\u7814\u7a76\u52a9\u7406",
  "\u786c\u9ad4\u5de5\u7a0b\u7814\u767c\u4e3b\u7ba1",
  "\u786c\u9ad4\u6e2c\u8a66\u5de5\u7a0b\u5e2b",
  "\u786c\u9ad4\u7814\u767c\u5de5\u7a0b\u5e2b",
  "\u793e\u5de5\u4eba\u54e1",
  "\u793e\u6703\uff0f\u4eba\u985e\u5b78\u7814\u7a76\u4eba\u54e1",
  "\u79d8\u66f8",
  "\u7a05\u52d9\u4eba\u54e1",
  "\u7a3d\u6838\u4eba\u54e1",
  "\u7a7a\u670d\u54e1",
  "\u7a7a\u8abf\u51b7\u51cd\u6280\u8853\u4eba\u54e1",
  "\u7bc0\u76ee\u52a9\u7406",
  "\u7bc0\u76ee\u88fd\u4f5c\u4eba\u54e1",
  "\u7c89\u672b\u51b6\u91d1\u6a21\u5177\u6280\u8853\u4eba\u54e1",
  "\u7cbe\u5bc6\u5100\u5668\u88fd\u9020\u5de5",
  "\u7cbe\u5bc6\u62cb\u5149\u6280\u8853\u4eba\u54e1",
  "\u7cfb\u7d71\u6574\u5408\uff0fERP\u5c08\u6848\u5e2b",
  "\u7cfb\u7d71\u7dad\u8b77\uff0f\u64cd\u4f5c\u4eba\u54e1",
  "\u7d21\u7e54\u5316\u5b78\u5de5\u7a0b\u5e2b",
  "\u7d21\u7e54\u5de5\u52d9",
  "\u7d50\u69cb\u6280\u5e2b",
  "\u7d71\u8a08\u5b78\u7814\u7a76\u54e1",
  "\u7d71\u8a08\u7cbe\u7b97\u4eba\u54e1",
  "\u7d93\u71df\u7ba1\u7406\u4e3b\u7ba1",
  "\u7db2\u7ad9\u884c\u92b7\u4f01\u5283",
  "\u7db2\u8def\u5b89\u5168\u5206\u6790\u5e2b",
  "\u7db2\u8def\u7ba1\u7406\u5de5\u7a0b\u5e2b",
  "\u7db2\u9801\u8a2d\u8a08\u5e2b",
  "\u7dda\u5207\u5272\u6280\u8853\u54e1",
  "\u7e3d\u52d9\u4e3b\u7ba1",
  "\u7e3d\u52d9\u4eba\u54e1",
  "\u7e3d\u5e79\u4e8b",
  "\u7e3d\u6a5f\u4eba\u54e1",
  "\u7e54\u54c1\u8a2d\u8a08",
  "\u7f8e\u59ff\u7f8e\u5100\u4eba\u54e1",
  "\u7f8e\u5bb9\u5de5\u4f5c\u8005",
  "\u7f8e\u5bb9\u985e\u52a9\u7406",
  "\u7f8e\u7532\u5f69\u7e6a\u5e2b",
  "\u7f8e\u7642\uff0f\u82b3\u7642\u5e2b",
  "\u7f8e\u8853\u8001\u5e2b",
  "\u7f8e\u8853\u8a2d\u8a08",
  "\u7f8e\u9aee\u5de5\u4f5c\u8005",
  "\u7f8e\u9aee\u985e\u52a9\u7406",
  "\u7ffb\u8b6f\uff0f\u53e3\u8b6f\u4eba\u54e1",
  "\u8072\u5b78\uff0f\u566a\u97f3\u5de5\u7a0b\u5e2b",
  "\u8072\u6a02\u5bb6",
  "\u8077\u80fd\u6cbb\u7642\u5e2b",
  "\u80a1\u52d9\u4eba\u54e1",
  "\u81ea\u52d5\u63a7\u5236\u5de5\u7a0b\u5e2b",
  "\u821e\u8e48\u6307\u5c0e\u8207\u821e\u8e48\u5bb6",
  "\u8239\u52d9\uff0f\u62bc\u532f\uff0f\u5831\u95dc\u4eba\u54e1",
  "\u8239\u9577\uff0f\u5927\u526f\uff0f\u8239\u54e1",
  "\u82b1\u85dd\uff0f\u5712\u85dd\u4eba\u54e1",
  "\u82f1\u6587\u7ffb\u8b6f\uff0f\u53e3\u8b6f\u4eba\u54e1",
  "\u85dd\u8853\u54c1\uff0f\u73e0\u5bf6\u9451\u50f9\uff0f\u62cd\u8ce3\u9867\u554f",
  "\u85dd\u8853\u6307\u5c0e\uff0f\u7e3d\u76e3",
  "\u85e5\u5b78\u52a9\u7406",
  "\u85e5\u5e2b",
  "\u878d\u8cc7\uff0f\u4fe1\u7528\u696d\u52d9\u4eba\u54e1",
  "\u884c\u653f\u4e3b\u7ba1",
  "\u884c\u653f\u4eba\u54e1",
  "\u884c\u653f\u52a9\u7406",
  "\u884c\u92b7\u4f01\u5283\u4e3b\u7ba1",
  "\u884c\u92b7\u4f01\u5283\u4eba\u54e1",
  "\u884c\u92b7\u4f01\u5283\u52a9\u7406",
  "\u88dc\u7fd2\u73ed\u5c0e\u5e2b\uff0f\u7ba1\u7406\u4eba\u54e1",
  "\u88dc\u7fd2\u73ed\u8001\u5e2b",
  "\u88fd\u978b\u985e\u4eba\u54e1",
  "\u897f\u9910\u5eda\u5e2b",
  "\u897f\u9ede\uff0f\u86cb\u7cd5\u5e2b",
  "\u8996\u807d\u5de5\u7a0b\u985e\u4eba\u54e1",
  "\u8a08\u7a0b\u8eca\u53f8\u6a5f",
  "\u8a18\u5e33\uff0f\u51fa\u7d0d\uff0f\u4e00\u822c\u6703\u8a08",
  "\u8a18\u8005\uff0f\u63a1\u7de8",
  "\u8a2d\u8a08\u52a9\u7406",
  "\u8a3a\u6240\u52a9\u7406",
  "\u8a9e\u6587\u88dc\u7fd2\u73ed\u8001\u5e2b",
  "\u8a9e\u8a00\u6cbb\u7642\u5e2b",
  "\u8abf\u9152\u5e2b\uff0f\u5427\u53f0\u4eba\u54e1",
  "\u8abf\u97f3\u6280\u8853\u54e1",
  "\u8b1b\u5e2b",
  "\u8b77\u7406\u5e2b",
  "\u8ca1\u52d9\u5206\u6790\u4eba\u54e1",
  "\u8ca1\u52d9\u6216\u6703\u8a08\u4e3b\u7ba1",
  "\u8ca1\u52d9\u6703\u8a08\u52a9\u7406",
  "\u8cc7\u6599\u5eab\u7ba1\u7406\u4eba\u54e1",
  "\u8cc7\u6599\u8f38\u5165\u4eba\u54e1",
  "\u8cc7\u6750\u4e3b\u7ba1",
  "\u8cc7\u6e90\u56de\u6536\u4eba\u54e1",
  "\u8cc7\u8a0a\u52a9\u7406\u4eba\u54e1",
  "\u8cc7\u8a0a\u5c08\u696d\u4eba\u54e1",
  "\u8cc7\u8a0a\u8a2d\u5099\u7ba1\u5236\u4eba\u54e1",
  "\u8eca\u5e8a\u4eba\u54e1",
  "\u8eca\u7e2b\uff0f\u88c1\u7e2b\u985e\u4eba\u54e1",
  "\u8edf\u97cc\u9ad4\u6e2c\u8a66\u5de5\u7a0b\u5e2b",
  "\u8edf\u9ad4\u5c08\u6848\u4e3b\u7ba1",
  "\u8edf\u9ad4\u5c08\u6848\u7ba1\u7406\u5e2b",
  "\u8edf\u9ad4\u8a2d\u8a08\u5de5\u7a0b\u5e2b",
  "\u8fb2\u5de5\u696d\u7528\u6a5f\u5668\u88dd\u4fee\u5de5",
  "\u8fb2\u6797\u696d\u8a2d\u5099\u64cd\u4f5c\u54e1",
  "\u8fb2\u85dd\u4f5c\u7269\u683d\u57f9\u5de5\u4f5c\u8005",
  "\u8fb2\u85dd\uff0f\u755c\u7522\u7814\u7a76\u4eba\u54e1",
  "\u901a\u4fe1\u6e2c\u8a66\u7dad\u4fee\u4eba\u54e1",
  "\u901a\u8a0a\u5de5\u7a0b\u7814\u767c\u4e3b\u7ba1",
  "\u901a\u8a0a\u8edf\u9ad4\u5de5\u7a0b\u5e2b",
  "\u901a\u8def\u958b\u767c\u4eba\u54e1",
  "\u9023\u9396\u5e97\u7ba1\u7406\u4eba\u54e1",
  "\u904a\u6232\u4f01\u5283\u4eba\u54e1",
  "\u904b\u52d5\u6559\u7df4",
  "\u904b\u8f38\u4ea4\u901a\u5c08\u696d\u4eba\u54e1",
  "\u904b\u8f38\u7269\u6d41\u985e\u4e3b\u7ba1",
  "\u90fd\u5e02\uff0f\u4ea4\u901a\u898f\u5283\u4eba\u54e1",
  "\u91ab\u4e8b\u653e\u5c04\u5e2b",
  "\u91ab\u4e8b\u6aa2\u9a57\u5e2b",
  "\u91ab\u5e2b",
  "\u91ab\u7642\u4eba\u54e1",
  "\u91ab\u7642\u5668\u6750\u7814\u767c\u5de5\u7a0b\u5e2b",
  "\u91ab\u7642\u5f9e\u696d\u4eba\u54e1",
  "\u91ab\u7642\u8a2d\u5099\u63a7\u5236\u4eba\u54e1",
  "\u91ab\u85e5\u696d\u52d9\u4ee3\u8868",
  "\u91ab\u85e5\u7814\u767c\u4eba\u54e1",
  "\u91ab\u9662\u884c\u653f\u7ba1\u7406\u4eba\u54e1",
  "\u91cf\u6e2c\uff0f\u5100\u6821\u4eba\u54e1",
  "\u91d1\u5c6c\u5efa\u6750\u67b6\u69cb\u4eba\u54e1",
  "\u91d1\u878d\u4ea4\u6613\u54e1",
  "\u91d1\u878d\u5c08\u696d\u4e3b\u7ba1",
  "\u91d1\u878d\u627f\u92b7\u54e1",
  "\u91d1\u878d\u71df\u696d\u54e1",
  "\u91d1\u878d\u7406\u8ca1\u5c08\u54e1",
  "\u91d1\u878d\u7814\u7a76\u54e1",
  "\u9280\u884c\u8fa6\u4e8b\u54e1",
  "\u9291\u5e8a\u4eba\u54e1",
  "\u934b\u7210\u64cd\u4f5c\u6280\u8853\u4eba\u54e1",
  "\u9435\u8def\u8eca\u8f1b\u99d5\u99db\u54e1",
  "\u9444\u9020\uff0f\u935b\u9020\u6a21\u5177\u6280\u8853\u4eba\u54e1",
  "\u9580\u5e02\uff0f\u5e97\u54e1\uff0f\u5c08\u6ac3\u4eba\u54e1",
  "\u9632\u6c34\u65bd\u5de5\u4eba\u54e1",
  "\u9632\u706b\u53ca\u5efa\u7bc9\u6aa2\u9a57\u4eba\u54e1",
  "\u96f6\u4ef6\u5de5\u7a0b\u5e2b",
  "\u96f7\u5c04\u64cd\u4f5c\u6280\u8853\u54e1",
  "\u96fb\u4fe1\u53ca\u96fb\u529b\u7dda\u8def\u67b6\u8a2d\u5de5",
  "\u96fb\u4fe1\uff0f\u901a\u8a0a\u7cfb\u7d71\u5de5\u7a0b\u5e2b",
  "\u96fb\u53f0\u5de5\u4f5c\u4eba\u54e1",
  "\u96fb\u5b50\u5546\u52d9\u6280\u8853\u4e3b\u7ba1",
  "\u96fb\u5b50\u5de5\u7a0b\u5e2b",
  "\u96fb\u5b50\u7522\u54c1\u7cfb\u7d71\u5de5\u7a0b\u5e2b",
  "\u96fb\u5b50\u8a2d\u5099\u88dd\u4fee\u5de5",
  "\u96fb\u6a5f\u5de5\u7a0b\u6280\u8853\u54e1",
  "\u96fb\u6a5f\u6280\u5e2b\uff0f\u5de5\u7a0b\u5e2b",
  "\u96fb\u6a5f\u88dd\u4fee\u5de5",
  "\u96fb\u6a5f\u8a2d\u5099\u88dd\u914d\u54e1",
  "\u96fb\u6e90\u5de5\u7a0b\u5e2b",
  "\u96fb\u73a9\u7a0b\u5f0f\u8a2d\u8a08\u5e2b",
  "\u96fb\u8166\u7cfb\u7d71\u5206\u6790\u5e2b",
  "\u96fb\u8166\u7d44\u88dd\uff0f\u6e2c\u8a66",
  "\u96fb\u8166\u7e6a\u5716\u4eba\u54e1",
  "\u96fb\u8166\u88dc\u7fd2\u73ed\u8001\u5e2b",
  "\u96fb\u8a71\u53ca\u96fb\u5831\u6a5f\u88dd\u4fee\u5de5",
  "\u96fb\u8a71\u5ba2\u670d\u985e\u4eba\u54e1",
  "\u96fb\u8a71\u884c\u92b7\u4eba\u54e1",
  "\u96fb\u934d\uff0f\u8868\u9762\u8655\u7406\u6280\u8853\u4eba\u54e1",
  "\u97cc\u9ad4\u8a2d\u8a08\u5de5\u7a0b\u5e2b",
  "\u97f3\u6a02\u5bb6",
  "\u97f3\u6a02\u8001\u5e2b",
  "\u9818\u73ed",
  "\u9818\u968a",
  "\u985e\u5eda\u5e2b",
  "\u985e\u6bd4IC\u8a2d\u8a08\u5de5\u7a0b\u5e2b",
  "\u985e\u8b1b\u5e2b",
  "\u9867\u554f\u4eba\u54e1",
  "\u98db\u5b89\u4eba\u54e1",
  "\u98db\u6a5f\u88dd\u4fee\u5de5",
  "\u98db\u884c\u6a5f\u5e2b",
  "\u98df\u54c1\u7814\u767c\u4eba\u54e1",
  "\u98df\u54c1\u885b\u751f\u7ba1\u7406\u5e2b",
  "\u98ef\u5e97\u5de5\u4f5c\u4eba\u54e1",
  "\u98ef\u5e97\u9910\u5ef3\u4e3b\u7ba1",
  "\u9910\u5eda\u52a9\u624b",
  "\u9910\u98f2\u670d\u52d9\u751f",
  "\u99d0\u6821\u4ee3\u8868",
  "\u9a57\u5149\u5e2b",
  "\u9eb5\u5305\u5e2b",
  "\u9ebb\u9189\u91ab\u5e2b"
)
#' Job provider for Taiwan
#'
#' @inherit JobProvider description details return
#' @family zh
#' @family TW
#' @export
#' @examples
#' x <- JobProvider_zh_TW$new()
#' x$render()
JobProvider_zh_TW <- R6::R6Class(
  inherit = JobProvider,
  "JobProvider_zh_TW",
  private = list(
    locale_ = "zh_TW",
    formats = job_formats_zh_tw
  )
)
